@@ -43,6 +43,7 @@
  */
 
 #include <stdio.h>
+#include <errno.h>
 #include <time.h>
 #include <sys/file.h>
 #include <sys/ioctl.h>
@@ -187,7 +188,8 @@ main(
     /* initialize APM Interface */
     if ((apmfd = open(APMDEV21, O_RDWR)) == -1) {
 	if ((apmfd = open(APMDEV22, O_RDWR)) == -1) {
-	    fprintf(stderr, "xbatt: cannot open apm device\n");
+ 	    fprintf(stderr, "xbatt: cannot open apm device (%s or %s): %s\n",
+        		APMDEV21, APMDEV22, strerror(errno));
 	    exit(1);
 	}
     }
